/***************************************************************************
 *            qof-expenses.h
 *
 *  Thu Oct 21 08:18:44 2004
 *  Copyright  2004-2007  Neil Williams  <linux@codehelp.co.uk>
 ****************************************************************************/
/*
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
/** @addtogroup QOF
	@{ */
/** @addtogroup Exp Expenses

	Like ::DB, Expenses uses UTC time within QOF and sets localtime when
	calling pilot-link code.

	\note pack_Expense still uses the old prototype
	using 0xffff instead of pi_buf->used. exp_pack has
	been modified to set pi_buf->used from the length returned
	by pack_Expense. Other databases already support pi_buffer
	and if expense is updated, this will need to be changed.

	@{ */
/** @file  qof-expenses.h
	@brief QOF expense definitions for pilot-link
	@author Copyright (c) 2004-2007 Neil Williams <linux@codehelp.co.uk>
*/

#ifndef _PQOF_EXPENSES_H
#define _PQOF_EXPENSES_H

#include "pi-expense.h"

#define PILOT_LINK_QOF_EXPENSES "pilot_expenses"
#define EXP_DATE      "expense_date"
#define EXP_TYPE      "type_of_expense"
#define EXP_PAYMENT   "form_of_payment"
#define EXP_CURRENCY  "currency_code"
#define EXP_AMOUNT    "expense_amount"
#define EXP_ATTENDEES "expense_attendees"
#define EXP_NOTE      "expense_note"
#define EXP_CATEGORY  "category"
#define EXP_DISTANCE  "distance_unit"
#define EXP_VENDOR    "expense_vendor"
#define EXP_CITY      "expense_city"
#define EXP_KVP       "currency_lookup"

/** type:  KVP_TYPE_STRING */
#define PQ_CURRENCY_MNEMONIC "expense/currency/mnemonic"
/** type:  KVP_TYPE_STRING */
#define PQ_CURRENCY_SYMBOL   "expense/currency/symbol"
/** type:  KVP_TYPE_GINT64 */
#define PQ_CURRENCY_FRACTION "expense/currency/fraction"

/** Expense Preferences identifier. */
#define PQ_EXPENSE_PREF Expense_Pref

/** Inherited from pilot-link because the exported form using makelong
is not constant. */
#define EXPENSE_CREATOR "exps"

/** \brief Register this object with QOF
*/
gboolean PQExpensesRegister (void);

typedef struct Expense Expense_t;

Expense_t * pq_expense_get_pilot (QofEntity * inst);

void
populate_currencies (void);

gint32
pq_set_currency (QofInstance * inst, gchar * mnemonic);

#endif /* _PQOF_EXPENSES_H */

/** @} */
/** @} */
